@@ -1,9 +1,9 @@
-from operator import mul
 from functools import reduce
+from operator import mul
 
 import numpy as np
-from numpy.random import randint
 from numpy.lib import Arrayterator
+from numpy.random import randint
 from numpy.testing import assert_
 
 
@@ -11,13 +11,12 @@ def test():
     np.random.seed(np.arange(10))
 
     # Create a random array
-    ndims = randint(5)+1
-    shape = tuple(randint(10)+1 for dim in range(ndims))
+    ndims = randint(5) + 1
+    shape = tuple(randint(10) + 1 for dim in range(ndims))
     els = reduce(mul, shape)
-    a = np.arange(els)
-    a.shape = shape
+    a = np.arange(els).reshape(shape)
 
-    buf_size = randint(2*els)
+    buf_size = randint(2 * els)
     b = Arrayterator(a, buf_size)
 
     # Check that each block has at most ``buf_size`` elements
@@ -29,8 +28,8 @@ def test():
 
     # Slice arrayterator
     start = [randint(dim) for dim in shape]
-    stop = [randint(dim)+1 for dim in shape]
-    step = [randint(dim)+1 for dim in shape]
+    stop = [randint(dim) + 1 for dim in shape]
+    step = [randint(dim) + 1 for dim in shape]
     slice_ = tuple(slice(*t) for t in zip(start, stop, step))
     c = b[slice_]
     d = a[slice_]
